@@ -15,3 +15,6 @@ RET_SYSTEM = -9999
 
 # 非debug，异常时的返回
 ERROR_INTERNAL = u'internal error'
+
+# 每次loop的超时
+LOOP_TIMEOUT = 30.0
\ No newline at end of file
