@@ -27,6 +27,7 @@ import asynchat
 import socket
 import functools
 import constants
+import select
 from base import CallBackMgr
 
 
@@ -131,7 +132,7 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
         self.bind((host, port))
         self.listen(self.request_queue_size)
 
-        asyncore.loop(use_poll=True, map=self._map)
+        self._loop()
 
     def make_rsp(self, *args, **kwargs):
         """
@@ -139,6 +140,22 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
         """
         return json.dumps(dict(*args, **kwargs)) + self.terminator
 
+    def _loop(self):
+        if hasattr(select, 'poll'):
+            poll_fun = asyncore.poll2
+        else:
+            poll_fun = asyncore.poll
+
+        while self._map:
+            poll_fun(constants.LOOP_TIMEOUT, self._map)
+            # after_loop_func_list
+            for func in self.server.after_loop_func_list:
+                try:
+                    func()
+                except Exception, e:
+                    self.server.logger.error('after_loop_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                             func.__name__, e, __import__('traceback').format_exc())
+
 
 class GourdTcpRequestHandler(asynchat.async_chat):
     server = None
@@ -210,7 +227,7 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
         self.create_socket(socket.AF_INET, socket.SOCK_DGRAM)
         self.bind((host, port))
 
-        asyncore.loop(use_poll=True, map=self._map)
+        self._loop()
 
     def make_rsp(self, *args, **kwargs):
         """
@@ -218,6 +235,22 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
         """
         return json.dumps(dict(*args, **kwargs))
 
+    def _loop(self):
+        if hasattr(select, 'poll'):
+            poll_fun = asyncore.poll2
+        else:
+            poll_fun = asyncore.poll
+
+        while self._map:
+            poll_fun(constants.LOOP_TIMEOUT, self._map)
+            # after_loop_func_list
+            for func in self.server.after_loop_func_list:
+                try:
+                    func()
+                except Exception, e:
+                    self.server.logger.error('after_loop_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                             func.__name__, e, __import__('traceback').format_exc())
+
 
 class GourdUdpRequestHandler(object):
     server = None
